/*
 * Copyright 2021-2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opentest4j.reporting.tooling.core.validator;

import org.apiguardian.api.API;

import static org.apiguardian.api.API.Status.EXPERIMENTAL;

/**
 * Validation message with severity and location.
 *
 * @param severity the severity of the message
 * @param location the location of the message
 * @param message the message
 * @since 0.1.0
 */
@API(status = EXPERIMENTAL, since = "0.1.0")
public record ValidationMessage(Severity severity, Location location, String message) {
	@Override
	public String toString() {
		return String.format("[%s] %s - %s", severity, location, message);
	}
}
